@@ -1,23 +1,13 @@
 /*
  *  DBD::mysql - DBI driver for the mysql database
  *
- *  Copyright (c) 1997, 1998  Jochen Wiedmann
+ *  Copyright (c) 2003       Rudolf Lippan
+ *  Copyright (c) 1997-2003  Jochen Wiedmann
  *
  *  You may distribute this under the terms of either the GNU General Public
- *  License or the Artistic License, as specified in the Perl README file,
- *  with the exception that it cannot be placed on a CD-ROM or similar media
- *  for commercial distribution without the prior approval of the author.
+ *  License or the Artistic License, as specified in the Perl README file.
  *
- *  Author:  Jochen Wiedmann
- *           Am Eisteich 9
- *           72555 Metzingen
- *           Germany
- *
- *           Email: joe@ispsoft.de
- *           Fax: +49 7123 / 14892
- *
- *
- *  $Id: dbdimp.c,v 1.9 2003/06/24 05:37:25 rlippan Exp $
+ *  $Id: dbdimp.c,v 1.11 2003/10/17 17:20:50 rlippan Exp $
  */
 
 
@@ -292,7 +282,6 @@ int BindParam(imp_sth_ph_t* ph, SV* value, IV sql_type) {
         (void) SvREFCNT_dec(ph->value);
     }
     ph->value = newSVsv(value);
-    (void) SvREFCNT_inc(value);
     if (sql_type) {
         ph->type = sql_type;
     }
